@@ -17,6 +17,12 @@
 #    under the License.
 
 import collections
+# TODO(smcginnis) update this once six has support for collections.abc
+# (https://github.com/benjaminp/six/pull/241) or clean up once we drop py2.7.
+try:
+    from collections.abc import Iterable
+except ImportError:
+    from collections import Iterable
 import contextlib
 import inspect as pyinspect
 import itertools
@@ -181,7 +187,9 @@ def paginate_query(query, model, limit, sort_keys, marker=None,
         LOG.warning('Unique keys not in sort_keys. '
                     'The sorting order may be unstable.')
 
-    assert(not (sort_dir and sort_dirs))
+    if sort_dir and sort_dirs:
+        raise AssertionError('Disallow set sort_dir and '
+                             'sort_dirs at the same time.')
 
     # Default the sort direction to ascending
     if sort_dirs is None and sort_dir is None:
@@ -191,7 +199,8 @@ def paginate_query(query, model, limit, sort_keys, marker=None,
     if sort_dirs is None:
         sort_dirs = [sort_dir for _sort_key in sort_keys]
 
-    assert(len(sort_dirs) == len(sort_keys))
+    if len(sort_dirs) != len(sort_keys):
+        raise AssertionError('sort_dirs and sort_keys must have same length.')
 
     # Add sorting
     for current_sort_key, current_sort_dir in zip(sort_keys, sort_dirs):
@@ -277,8 +286,7 @@ def paginate_query(query, model, limit, sort_keys, marker=None,
 def to_list(x, default=None):
     if x is None:
         return default
-    if not isinstance(x, collections.Iterable) or \
-            isinstance(x, six.string_types):
+    if not isinstance(x, Iterable) or isinstance(x, six.string_types):
         return [x]
     elif isinstance(x, list):
         return x
@@ -1152,7 +1160,8 @@ def suspend_fk_constraints_for_col_alter(
             fks = []
             for ref_table_name in referents:
                 for fk in insp.get_foreign_keys(ref_table_name):
-                    assert fk.get('name')
+                    if not fk.get('name'):
+                        raise AssertionError("foreign key hasn't a name.")
                     if fk['referred_table'] == table_name and \
                             column_name in fk['referred_columns']:
                         fk['source_table'] = ref_table_name
